<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package sin
 */

if (!function_exists('sin_post_excerpt')) {
  function sin_post_excerpt() {
    $excerpt_type = get_theme_mod('blog_excerpt_type', 'excerpt');
    if ($excerpt_type == 'excerpt') {
      ?>

      <!-- excerpt -->
      <div class="entry-content clearfix">
        <?php the_excerpt(); ?>
      </div>
      <!-- end excerpt -->

      <?php
    } else {
      ?>

      <!-- excerpt (post content) -->
      <div class="entry-content clearfix">
        <?php the_content('[...]', false); ?>
      </div>
      <!-- end excerpt (post content) -->

      <?php
    }
  }
}

if (!function_exists('sin_page_header')) {
  function sin_page_header(){
    // author page
    if (is_author()) {
?>
      <header class="page-header">
        <h1 class="page-title"><?php the_archive_title();?></h1>
        <?php if (get_the_author_meta('description')) { ?>
        <div class="archive-description"><?php the_author_meta('description'); ?></div>
        <?php }?>
      </header><!-- .page-header -->
<?php
    // category/tag page
    } else if (is_category() || is_tag()) {
?>
      <header class="page-header">
        <h1 class="page-title"><?php the_archive_title();?></h1>
        <?php if (get_the_archive_description()) { ?>
        <div class="archive-description"><?php the_archive_description();?></div>
        <?php }?>
      </header><!-- .page-header -->
<?php
    // search results page
    } else if (is_search()) { 
?>
      <header class="page-header">
        <h1 class="page-title"><?php printf( esc_html__( 'Search Results for: %s', 'sin' ), '<span>' . get_search_query() . '</span>' );?></h1>
      </header><!-- .page-header -->
<?php
    // archive page
    } else if (is_archive()) {
?>
      <header class="page-header">
        <h1 class="page-title"><?php the_archive_title();?></h1>
      </header><!-- .page-header -->
<?php
    }
  }
}

if (!function_exists('sin_excerpt_length')) {
  function sin_excerpt_length($length) {
    $excerpt_length = get_theme_mod('blog_excerpt_length', 40);
    if ($excerpt_length) {
      $excerpt_length = intval($excerpt_length);
    } else {
      $excerpt_length = 40;
    }
    return $excerpt_length;
  }
}
add_filter('excerpt_length', 'sin_excerpt_length');

if (!function_exists('sin_editor_style')) {
  function sin_editor_style() {

    // add stylesheets
    add_editor_style(array(
      'assets/css/editor-style.css',
      'assets/font-awesome/css/font-awesome.min.css'
    ));

  }
}
add_action('init', 'sin_editor_style');

if (!function_exists('sin_get_custom_style')) {
  function sin_get_custom_style(){
    $css = '';
    $primary_color = esc_attr( get_theme_mod( 'theme_color' ) );
    if ( $primary_color ) {
        $primary_color = '#'.$primary_color;
$css .= '
blockquote{
  border-left: 4px solid '.$primary_color.';
}
button,
input[type="button"],
input[type="reset"],
input[type="submit"] {
  background: '.$primary_color.';
}
input[type="text"]:focus,
input[type="email"]:focus,
input[type="url"]:focus,
input[type="password"]:focus,
input[type="search"]:focus,
input[type="number"]:focus,
input[type="tel"]:focus,
input[type="range"]:focus,
input[type="date"]:focus,
input[type="month"]:focus,
input[type="week"]:focus,
input[type="time"]:focus,
input[type="datetime"]:focus,
input[type="datetime-local"]:focus,
input[type="color"]:focus,
textarea:focus {
  border:1px solid '.$primary_color.';
}
a {
  color: '.$primary_color.';
}
a:hover,
a:focus,
a:active {
  color: '.$primary_color.';
}
.site-title a:hover,
.site-title a:focus,
.site-title a:active{
  color:'.$primary_color.';
}
.main-navigation .menu >li >a:hover,
.main-navigation .menu >li >a:focus{
  color:'.$primary_color.';
}
.main-navigation .menu >li ul li a:hover,
.main-navigation .menu >li ul li a:focus{
  color:'.$primary_color.';
}
.entry-title a:hover,
.entry-title a:focus{
  color:'.$primary_color.';
}
.sticky .entry-info{
  border-bottom:2px solid '.$primary_color.';
}
.sticky .entry-title,
.sticky .entry-title a{
  color:'.$primary_color.';
}
.entry-footer a:hover,
.entry-footer a:focus{
  color:'.$primary_color.';
}
.widget a:hover,
.widget a:focus{
  color:'.$primary_color.';
}
.comment-form .logged-in-as a:hover,
.comment-form .logged-in-as a:focus{
  color:'.$primary_color.';
}
.posts-navigation a:hover,
.posts-navigation a:focus{
  color:'.$primary_color.';
}
.post-navigation a:hover,
.post-navigation a:focus{
  color: '.$primary_color.';
}
.pagination .nav-links a:hover,
.pagination .nav-links a:focus{
  background:'.$primary_color.';
}
.pagination .nav-links .current{
  background:'.$primary_color.';
}
.site-info a:hover,
.site-info a:focus{
  color:'.$primary_color.';
}
#back_top{
  background:'.$primary_color.';
}
';
    }
    return $css;
  }
}
